div#status {
  min-height: 100%;
  height: 100%;
  margin: 0px;
}
textarea.output {
  font-size: 12px;
  background: #fff;
  height: 100%;
  border: 1px solid lightgray;
  width: 100%;
  overflow-y: auto;
  resize: none;
  padding: 8px;
  outline: none;
}
iframe.output {
  background-color: #fff;
  border: 1px solid lightgray;
  padding: 0px;
  overflow-y: auto;
  height: 100%;
  width: 100%;
}
pre#print_pre {
  white-space: pre-wrap;
  word-wrap: break-word;
  display: none;
}
.directory {
  font-weight: bold;
  margin-bottom: 0px;
}
#pills {
  min-width: 200px;
}
.ms-10 {
  margin-left: 10px;
}
.me-10 {
  margin-right: 10px;
}
.fs-85 {
  font-size: 85%;
}
.hide {
  display: none !important;
}
.nosb {
  overflow-y: scroll;
  scrollbar-width: none;
  -ms-overflow-style: none;
}
.nosb::-webkit-scrollbar {
  width: 0px;
}
@media print {
  div#wrap, div#footer {
    display: none;
  }
  pre#print_pre {
    display: block;
  }
}
